==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_entities/equiplinearref_001/OverviewDetails.java <==

package net.datastream.schemas.mp_entities.equiplinearref_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.DOCUMENTID_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}DISPLAYONOVERVIEW" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}COLOR" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ICONCODE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ICONPATH" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ICONIMAGE" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "displayonoverview",
    "color",
    "iconcode",
    "iconpath",
    "iconimage"
})
@XmlRootElement(name = "OverviewDetails")
public class OverviewDetails {

    @XmlElement(name = "DISPLAYONOVERVIEW", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "true")
    protected String displayonoverview;
    @XmlElement(name = "COLOR", namespace = "http://schemas.datastream.net/MP_fields")
    protected String color;
    @XmlElement(name = "ICONCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String iconcode;
    @XmlElement(name = "ICONPATH", namespace = "http://schemas.datastream.net/MP_fields")
    protected String iconpath;
    @XmlElement(name = "ICONIMAGE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DOCUMENTID_Type iconimage;

    /**
     * Gets the value of the displayonoverview property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDISPLAYONOVERVIEW() {
        return displayonoverview;
    }

    /**
     * Sets the value of the displayonoverview property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDISPLAYONOVERVIEW(String value) {
        this.displayonoverview = value;
    }

    /**
     * Gets the value of the color property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOLOR() {
        return color;
    }

    /**
     * Sets the value of the color property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOLOR(String value) {
        this.color = value;
    }

    /**
     * Gets the value of the iconcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getICONCODE() {
        return iconcode;
    }

    /**
     * Sets the value of the iconcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setICONCODE(String value) {
        this.iconcode = value;
    }

    /**
     * Gets the value of the iconpath property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getICONPATH() {
        return iconpath;
    }

    /**
     * Sets the value of the iconpath property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setICONPATH(String value) {
        this.iconpath = value;
    }

    /**
     * Gets the value of the iconimage property.
     * 
     * @return
     *     possible object is
     *     {@link DOCUMENTID_Type }
     *     
     */
    public DOCUMENTID_Type getICONIMAGE() {
        return iconimage;
    }

    /**
     * Sets the value of the iconimage property.
     * 
     * @param value
     *     allowed object is
     *     {@link DOCUMENTID_Type }
     *     
     */
    public void setICONIMAGE(DOCUMENTID_Type value) {
        this.iconimage = value;
    }

}

==> eam-wshub-proxyclient-12.1-4-sources.jar: net/datastream/schemas/mp_entities/equiplinearref_001/OverviewDetails.java <==

package net.datastream.schemas.mp_entities.equiplinearref_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.DOCUMENTID_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DISPLAYONOVERVIEW" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COLOR" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ICONCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ICONPATH" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ICONIMAGE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "displayonoverview",
    "color",
    "iconcode",
    "iconpath",
    "iconimage"
})
@XmlRootElement(name = "OverviewDetails")
public class OverviewDetails {

    @XmlElement(name = "DISPLAYONOVERVIEW", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "true")
    protected String displayonoverview;
    @XmlElement(name = "COLOR", namespace = "http://schemas.datastream.net/MP_fields")
    protected String color;
    @XmlElement(name = "ICONCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String iconcode;
    @XmlElement(name = "ICONPATH", namespace = "http://schemas.datastream.net/MP_fields")
    protected String iconpath;
    @XmlElement(name = "ICONIMAGE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DOCUMENTID_Type iconimage;

    /**
     * Gets the value of the displayonoverview property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDISPLAYONOVERVIEW() {
        return displayonoverview;
    }

    /**
     * Sets the value of the displayonoverview property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDISPLAYONOVERVIEW(String value) {
        this.displayonoverview = value;
    }

    /**
     * Gets the value of the color property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOLOR() {
        return color;
    }

    /**
     * Sets the value of the color property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOLOR(String value) {
        this.color = value;
    }

    /**
     * Gets the value of the iconcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getICONCODE() {
        return iconcode;
    }

    /**
     * Sets the value of the iconcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setICONCODE(String value) {
        this.iconcode = value;
    }

    /**
     * Gets the value of the iconpath property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getICONPATH() {
        return iconpath;
    }

    /**
     * Sets the value of the iconpath property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setICONPATH(String value) {
        this.iconpath = value;
    }

    /**
     * Gets the value of the iconimage property.
     * 
     * @return
     *     possible object is
     *     {@link DOCUMENTID_Type }
     *     
     */
    public DOCUMENTID_Type getICONIMAGE() {
        return iconimage;
    }

    /**
     * Sets the value of the iconimage property.
     * 
     * @param value
     *     allowed object is
     *     {@link DOCUMENTID_Type }
     *     
     */
    public void setICONIMAGE(DOCUMENTID_Type value) {
        this.iconimage = value;
    }

}
